==> haskell-optparse-simple-0.1.1.2-137-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-optparse-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 optparse-simple
version:              0.1.1.2
visibility:           public
id:                   optparse-simple-0.1.1.2-4cZEHKb9ZAyEw41INKQRpG
key:                  optparse-simple-0.1.1.2-4cZEHKb9ZAyEw41INKQRpG
license:              BSD-3-Clause
copyright:            2015-2017 FP Complete
maintainer:           chrisdone@fpcomplete.com
author:               FP Complete
homepage:             https://github.com/fpco/optparse-simple#readme
synopsis:             Simple interface to optparse-applicative
description:
    Please see the README at <https://www.stackage.org/package/optparse-simple>

category:             Options
abi:                  81daf29575fa4b838026349e37853f2e
exposed:              True
exposed-modules:      Options.Applicative.Simple
hidden-modules:       Paths_optparse_simple
import-dirs:          /usr/lib/ghc-8.8.3/site-local/optparse-simple-0.1.1.2
library-dirs:         /usr/lib/ghc-8.8.3/site-local/optparse-simple-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/optparse-simple-0.1.1.2
hs-libraries:         HSoptparse-simple-0.1.1.2-4cZEHKb9ZAyEw41INKQRpG
depends:
    base-4.13.0.0 githash-0.1.3.3-6Eu9P4eDvztDHjk2FHvm9W
    optparse-applicative-0.15.1.0-An71inc1YsbDQpJMiwk4K7
    template-haskell-2.15.0.0 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-optparse-simple/html/optparse-simple.haddock

haddock-html:         /usr/share/doc/haskell-optparse-simple/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-optparse-simple-0.1.1.2-149-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-optparse-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 optparse-simple
version:              0.1.1.2
visibility:           public
id:                   optparse-simple-0.1.1.2-442IP5Z5sIZHBolegxqzpY
key:                  optparse-simple-0.1.1.2-442IP5Z5sIZHBolegxqzpY
license:              BSD-3-Clause
copyright:            2015-2017 FP Complete
maintainer:           chrisdone@fpcomplete.com
author:               FP Complete
homepage:             https://github.com/fpco/optparse-simple#readme
synopsis:             Simple interface to optparse-applicative
description:
    Please see the README at <https://www.stackage.org/package/optparse-simple>

category:             Options
abi:                  90454be4f758bb52749639791d1eaceb
exposed:              True
exposed-modules:      Options.Applicative.Simple
hidden-modules:       Paths_optparse_simple
import-dirs:          /usr/lib/ghc-8.8.3/site-local/optparse-simple-0.1.1.2
library-dirs:         /usr/lib/ghc-8.8.3/site-local/optparse-simple-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/optparse-simple-0.1.1.2
hs-libraries:         HSoptparse-simple-0.1.1.2-442IP5Z5sIZHBolegxqzpY
depends:
    base-4.13.0.0 githash-0.1.3.3-AsPZDeskH1N6hUz80uIfFU
    optparse-applicative-0.15.1.0-An71inc1YsbDQpJMiwk4K7
    template-haskell-2.15.0.0 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-optparse-simple/html/optparse-simple.haddock

haddock-html:         /usr/share/doc/haskell-optparse-simple/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
